@@ -20,8 +20,9 @@ from .stack_layout import StackFrame, StackLayout
 from .terminal import Terminal
 from .utils import is_selectable
 
-version = "1.4.9"
+version = "1.4.10"
 
+# TODO object highlighted on stack view should be shown on the overview
 # TODO Backspace exit help
 # TODO support ctrl-a + (whatever emacs keybinding to go to end of line)
 #  https://www.gnu.org/software/bash/manual/html_node/Commands-For-Moving.html
@@ -462,7 +463,6 @@ class ObjExploreApp:
 
 def explore(obj: Any) -> Any:
     """ Run the explorer on the given object """
-    breakpoint()
     # Get the name of the variable sent to this function
     # If someone calls this function like:
     # >>> df = pandas.DataFrame()
